{% for item in items %}

    <div class="feed un-read" id="{{ item.id }}" style='border-bottom: 1px solid #999; padding-bottom:12px;'>
    <h2><a href="{{ item.link }}" target="_blank">{{ item.title }}</a> <small>{{ item.feed.title }}</small></h2>
    <p><span>{{ item.pub_date }}</span></p>
    {{ item.content|safe }}
    </div>
{% endfor %}